==> fop2-2.24-debian-x86_64.tgz: fop2/html/js/lang_se.js <==
// Translated by Mikael Carlsson
// FreePBX Development Team

lang['incoming_call']      = 'Inkommande samtal';
lang['connecting_server']  = 'Kopplar upp till servern, försök nummer ';

lang['from_queue']         = "Från kö:";
lang['number']             = "Nummer:";
lang['name']               = "Namn:";

lang['dial']               = 'Ring';
lang['transfer_vmail']     = 'Koppla till röstbrevlåda';
lang['transfer_external']  = 'koppla till mobil';
lang['attendant_transfer'] = 'Koppla';
lang['spy']                = 'Lyssna';
lang['whisper']            = 'Lyssna och viska';
lang['pickup']             = "Plocka upp samtal";
lang['hangup']             = 'Lägg på';
lang['filter']             = 'Filtrera';

lang['enter_sec_code']     = 'Inloggningsdetaljer';
lang['exten']              = 'Anknytning:';
lang['password']           = 'Lösenord:';

lang['confirm_hangup']     = 'Bekräfta lägg på';
lang['areyousure']         = 'Är du säker?';
lang['yes']                = 'Ja';
lang['no']                 = 'Nej';

lang['paused']             = 'Pausad';
lang['set_information']    = 'Set Information';
lang['member_of']          = 'Medlem av ';
lang['not_available']      = 'Systemet är inte tillgängligt just nu';
lang['not_connect']        = 'Kan inte koppla till servern';
lang['one_moment']         = 'Ett ögonblick';
lang['no_results']         = 'Inga resultat hittades';

lang['toggle_lock']        = 'Lås/lås upp konferens';
lang['toggle_muteall']     = 'Ljud av/på alla användare';
lang['available']          = 'Tillgänglig';
lang['phonebook']          = 'Telefonbok';
lang['toggle_mute']        = 'Växla ljud av/på';
lang['kick']               = 'Kasta ut användare';
lang['record']             = 'Spela in samtal';
lang['presence_noti']      = 'Meddela närvaro';

lang['queues']             = 'Köer';
lang['extensions']         = 'Anknytningar';
lang['trunks']             = 'Trunkar';
lang['conferences']        = 'Konferenser';
lang['other']              = 'Annat';
lang['enter_state']        = 'Skriv in värde';
lang['parkingslots']       = 'Parkeringsplats';

lang['enter_reg_code']     = 'Skriv in registreringskod:';
lang['reg_code']           = 'Registreringskod:';
lang['reg_name']           = 'Registreringsnamn:';

lang['remove_member']      = 'Ta bort medlem';
lang['remove_member_from'] = 'Ta bort från ';
lang['pause_member']       = 'Pausa medlem';
lang['unpause_member']     = 'Återuppta medlem';
lang['add_member']         = 'Lägg till ';
lang['pickup_call']        = 'Plocka upp samtal';
lang['email_user']         = 'Skicka e-post';
lang['send_sms']           = 'Skicka SMS';
lang['message']            = 'Meddelande:';
lang['sending']            = 'Sändning...';
lang['noResponse']         = 'Inget svar.';

lang['chat']               = 'Chatt';
lang['notlogged']          = 'Användaren är inte inloggad. Sparar notering.';
lang['me']                 = 'Mig';
lang['clearchat']          = 'Rensa chattfönster';
lang['note']               = 'Notering';
lang['toggle_sound']       = 'Växla ljud';
lang['says']               = 'säger';

lang['agents']             = 'Agent: %d';
lang['calls']              = 'Väntande samtal: %d';
lang['call_connected']     = 'Pratar med';
lang['changeDisplayType']  = 'Ändra bildskärmstyp';

lang['voicemail']          = 'Röstbrevlåda';
lang['vmail_new']          = 'Ny';
lang['vmail_old']          = 'Gammal';
lang['vmail_work']         = 'Arbete';
lang['vmail_family']       = 'Familjen';
lang['vmail_friends']      = 'Vänner';
lang['vmail_number']       = 'Nr.';
lang['vmail_date']         = 'Datum';
lang['vmail_callerid']     = 'Nummerpresentation';
lang['vmail_duration']     = 'Längd';

lang['preferences']        = 'Inställningar';
lang['summary']            = 'Summerad';
lang['detailed']           = 'Detaljerad';

lang['inactive_line']      = 'Linje %d inaktiv';
lang['inuse']              = '%d linjer används';
lang['vmail_count']        = 'Ny %d, gammal %d';
lang['logout']             = 'Logga ut'

lang['prefSounds']         = 'Ljud';
lang['prefDisplay']        = 'Skärm';

lang['labelSoundChat']     = 'Chattljud';
lang['labelSoundQueue']    = 'Köljud';
lang['labelSoundRing']     = 'Ringljud';

lang['labelDisplayQueue']          = 'Standard kövy:';
lang['labelDisplayDynamicLine']    = 'Dynamisk linjevisning:';
lang['labelDisplayNotifyDuration'] = 'Varaktighet för meddelande:';
lang['labelDisplayLanguage']       = 'Språk:';

// Internationalization strings DATE
dateFormat.i18n = {
        dayNames: [
                "Sön", "Mån", "Tis", "Ons", "Tor", "Fre", "Lör",
                "Söndag", "Måndag", "Tisdag", "Onsdag", "Torsdag", "Fridag", "Lördag"
        ],
        monthNames: [
                "Jan", "Feb", "Mar", "Apr", "Maj", "Jun", "Jul", "Aug", "Sep", "Okt", "Nov", "Dec",
                "Januari", "Februari", "Mars", "April", "Maj", "Juni", "Juli", "Augusti", "September", "Oktober", "November", "December"
        ]
};

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/js/lang_se.js <==
// Translated by Mikael Carlsson
// FreePBX Development Team

lang['incoming_call']      = 'Inkommande samtal';
lang['connecting_server']  = 'Kopplar upp till servern, försök nummer ';

lang['from_queue']         = "Från kö:";
lang['number']             = "Nummer:";
lang['name']               = "Namn:";

lang['dial']               = 'Ring';
lang['transfer_vmail']     = 'Koppla till röstbrevlåda';
lang['transfer_external']  = 'koppla till mobil';
lang['attendant_transfer'] = 'Koppla';
lang['blind_transfer']     = 'Blind Koppla';
lang['spy']                = 'Lyssna';
lang['whisper']            = 'Lyssna och viska';
lang['pickup']             = "Plocka upp samtal";
lang['hangup']             = 'Lägg på';
lang['filter']             = 'Filtrera';

lang['enter_sec_code']     = 'Inloggningsdetaljer';
lang['exten']              = 'Anknytning:';
lang['password']           = 'Lösenord:';

lang['confirm_hangup']     = 'Bekräfta lägg på';
lang['areyousure']         = 'Är du säker?';
lang['yes']                = 'Ja';
lang['no']                 = 'Nej';
lang['cancel']             = 'Avbryt';
lang['accept']             = 'Acceptera';

lang['paused']             = 'Pausad';
lang['set_information']    = 'Set Information';
lang['set_penalty']        = 'Straff';
lang['member_of']          = 'Medlem av ';
lang['not_available']      = 'Systemet är inte tillgängligt just nu';
lang['not_connect']        = 'Kan inte koppla till servern';
lang['one_moment']         = 'Ett ögonblick';
lang['no_results']         = 'Inga resultat hittades';

lang['toggle_lock']        = 'Lås/lås upp konferens';
lang['toggle_muteall']     = 'Ljud av/på alla användare';
lang['available']          = 'Tillgänglig';
lang['phonebook']          = 'Telefonbok';
lang['toggle_mute']        = 'Växla ljud av/på';
lang['kick']               = 'Kasta ut användare';
lang['record']             = 'Spela in samtal';
lang['presence_noti']      = 'Meddela närvaro';

lang['queues']             = 'Köer';
lang['extensions']         = 'Anknytningar';
lang['trunks']             = 'Trunkar';
lang['conferences']        = 'Konferenser';
lang['other']              = 'Annat';
lang['enter_state']        = 'Skriv in värde';
lang['parkingslots']       = 'Parkeringsplats';

lang['enter_reg_code']     = 'Skriv in registreringskod:';
lang['reg_code']           = 'Registreringskod:';
lang['reg_name']           = 'Registreringsnamn:';

lang['remove_member']      = 'Ta bort medlem';
lang['remove_member_from'] = 'Ta bort från ';
lang['pause_member']       = 'Pausa medlem';
lang['unpause_member']     = 'Återuppta medlem';
lang['add_member']         = 'Lägg till ';
lang['pickup_call']        = 'Plocka upp samtal';
lang['email_user']         = 'Skicka e-post';
lang['send_sms']           = 'Skicka SMS';
lang['message']            = 'Meddelande:';
lang['sending']            = 'Sändning...';
lang['noResponse']         = 'Inget svar.';
lang['calls_taken']        = 'Samtal tas:';
lang['penalty']            = 'Straff:';

lang['chat']               = 'Chatt';
lang['notlogged']          = 'Användaren är inte inloggad. Sparar notering.';
lang['me']                 = 'Mig';
lang['clearchat']          = 'Rensa chattfönster';
lang['note']               = 'Notering';
lang['toggle_sound']       = 'Växla ljud';
lang['says']               = 'säger';

lang['agents']             = 'Agent: %d';
lang['calls']              = 'Väntande samtal: %d';
lang['call_connected']     = 'Pratar med';
lang['changeDisplayType']  = 'Ändra bildskärmstyp';

lang['voicemail']          = 'Röstbrevlåda';
lang['vmail_new']          = 'Ny';
lang['vmail_old']          = 'Gammal';
lang['vmail_work']         = 'Arbete';
lang['vmail_family']       = 'Familjen';
lang['vmail_friends']      = 'Vänner';
lang['vmail_number']       = 'Nr.';
lang['vmail_date']         = 'Datum';
lang['vmail_callerid']     = 'Nummerpresentation';
lang['vmail_duration']     = 'Längd';
lang['play']               = 'Spela';
lang['download']           = 'Ladda';

lang['preferences']        = 'Inställningar';
lang['summary']            = 'Summerad';
lang['detailed']           = 'Detaljerad';

lang['inactive_line']      = 'Linje %d inaktiv';
lang['inuse']              = '%d linjer används';
lang['vmail_count']        = 'Ny %d, gammal %d';
lang['logout']             = 'Logga ut'

lang['prefSounds']         = 'Ljud';
lang['prefDisplay']        = 'Skärm';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = 'Telefon';

lang['labelSoundChat']     = 'Chattljud';
lang['labelSoundQueue']    = 'Köljud';
lang['labelSoundRing']     = 'Ringljud';

lang['labelDisplayQueue']          = 'Standard kövy';
lang['labelDisplayDynamicLine']    = 'Dynamisk linjevisning';
lang['labelDisplayNotifyDuration'] = 'Varaktighet för meddelande';
lang['labelDisplayLanguage']       = 'Språk';
lang['labelAutoPopup']             = 'Auto Popup';
lang['labelAutoAnswer']            = 'Automatiskt Svar';

lang['close']                      = 'Stänga';
lang['recordings']                 = 'Inspelningar';
lang['cdrrecords']                 = 'Samtalshistorik';

// Internationalization strings DATE
dateFormat.i18n = {
        dayNames: [
                "Sön", "Mån", "Tis", "Ons", "Tor", "Fre", "Lör",
                "Söndag", "Måndag", "Tisdag", "Onsdag", "Torsdag", "Fridag", "Lördag"
        ],
        monthNames: [
                "Jan", "Feb", "Mar", "Apr", "Maj", "Jun", "Jul", "Aug", "Sep", "Okt", "Nov", "Dec",
                "Januari", "Februari", "Mars", "April", "Maj", "Juni", "Juli", "Augusti", "September", "Oktober", "November", "December"
        ]
};
